AppStoreSubscription class

iOS App-Store subscription

Constructors

AppStoreSubscription({double? price, String? currency, String? transactionId, int? transactionDate, String? salesRegion, Map<String, String>? callbackParameters, Map<String, String>? partnerParameters})

Properties

callbackParameters Map<String, String>?
final
currency String?
final
hashCode int
The hash code for this object.
no setterinherited
partnerParameters Map<String, String>?
final
price double?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
salesRegion String?
final
transactionDate int?
final
transactionId String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited