EventAction enum

Built-in tapp event actions (CUSTOM == 0) Built-in tapp event actions

Inheritance
Available extensions

Values

custom → const EventAction
tapp_add_payment_info → const EventAction
tapp_add_to_cart → const EventAction
tapp_add_to_wishlist → const EventAction
tapp_complete_registration → const EventAction
tapp_contact → const EventAction
tapp_customize_product → const EventAction
tapp_donate → const EventAction
tapp_find_location → const EventAction
tapp_initiate_checkout → const EventAction
tapp_generate_lead → const EventAction
tapp_purchase → const EventAction
tapp_schedule → const EventAction
tapp_start_trial → const EventAction
tapp_submit_application → const EventAction
tapp_subscribe → const EventAction
tapp_view_content → const EventAction
tapp_click_button → const EventAction
tapp_download_file → const EventAction
tapp_join_group → const EventAction
tapp_achieve_level → const EventAction
tapp_create_group → const EventAction
tapp_create_role → const EventAction
tapp_apply_for_loan → const EventAction
tapp_loan_approval → const EventAction
tapp_loan_disbursal → const EventAction
tapp_login → const EventAction
tapp_rate → const EventAction
tapp_spend_credits → const EventAction
tapp_unlock_achievement → const EventAction
tapp_add_shipping_info → const EventAction
tapp_earn_virtual_currency → const EventAction
tapp_start_level → const EventAction
tapp_complete_level → const EventAction
tapp_post_score → const EventAction
tapp_select_content → const EventAction
tapp_begin_tutorial → const EventAction
tapp_complete_tutorial → const EventAction

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<EventAction>
A constant List of the values in this enum, in order of their declaration.