InitConfig class

——— Now the new types to match your React-Native API ——— Initialization options

Constructors

InitConfig({String? authToken, EnvironmentType? env, String? tappToken, AffiliateType? affiliate})

Properties

affiliate AffiliateType?
final
authToken String?
final
env EnvironmentType?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tappToken String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited