InnerConfig class

Constructors

InnerConfig({String? authToken, String? env, String? tappToken, String? affiliate, String? bundleID, String? appToken, String? deepLinkUrl, String? linkToken})
InnerConfig.fromMap(Map<String, dynamic>? m)
factory

Properties

affiliate String?
final
appToken String?
final
authToken String?
final
bundleID String?
final
deepLinkUrl String?
final
env String?
final
hashCode int
The hash code for this object.
no setterinherited
linkToken String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tappToken String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited