PlayStoreSubscription class

Android Play-Store subscription

Constructors

PlayStoreSubscription({double? price, String? currency, String? sku, String? orderId, String? signature, String? purchaseToken, int? purchaseTime})

Properties

currency String?
final
hashCode int
The hash code for this object.
no setterinherited
orderId String?
final
price double?
final
purchaseTime int?
final
purchaseToken String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signature String?
final
sku String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited