UpdateSkanConversionValueType class

SKAdNetwork conversion-value update

Constructors

UpdateSkanConversionValueType({int? value, String? coarseValue, int? lockWindow})

Properties

coarseValue String?
final
hashCode int
The hash code for this object.
no setterinherited
lockWindow int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited