VerifyPlayStorePurchaseType class
iOS-only verify+track-playstore purchase call
Constructors
- VerifyPlayStorePurchaseType({String? transactionId, String? productId})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- productId → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- transactionId → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited